ILifecycle class abstract

对lifecycle的接口

Implementers
Available extensions

Constructors

ILifecycle()

Properties

currentLifecycleState LifecycleState
当前状态
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addLifecycleObserver(LifecycleObserver observer, {LifecycleState? startWith, bool fullCycle = true}) → void
添加一个观测者
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeLifecycleObserver(LifecycleObserver observer, {LifecycleState? willEnd, bool? fullCycle}) → void
toLifecycle() Lifecycle

Available on ILifecycle, provided by the LifecycleConvertExt extension

toLifecycleRegistry() ILifecycleRegistry

Available on ILifecycle, provided by the LifecycleConvertExt extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited