LifecycleOwner class abstract
lifecycle的管理者
- Implemented types
- Implementers
- Available extensions
Constructors
Properties
- currentLifecycleState → LifecycleState
-
当前状态
no setteroverride
- debugLabel → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lifecycle → Lifecycle
-
no setteroverride
- lifecycleRegistry → LifecycleRegistry
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → dynamic
-
no setter
Methods
-
addLifecycleObserver(
LifecycleObserver observer, {LifecycleState? startWith, bool fullCycle = true}) → void -
添加一个观测者
override
-
addLifecycleObserverToOwner<
LO extends LifecycleOwner> (LifecycleObserver observer, {bool cycleCompanionOwner = false, bool test(LO)?}) → void -
Available on ILifecycleRegistry, provided by the LifecycleRegistryMixinExt extension
-
addOwnerAttachCallback(
LifecycleOwnerAttachCallback callback) → void -
Available on LifecycleOwner, provided by the LifecycleCallbackManager extension
-
addOwnerDetachCallback(
LifecycleOwnerDetachCallback callback) → void -
Available on LifecycleOwner, provided by the LifecycleCallbackManager extension
-
addRegistryAttachCallback(
LifecycleRegistryAttachCallback callback) → void -
Available on LifecycleOwner, provided by the LifecycleCallbackManager extension
-
addRegistryDetachCallback(
LifecycleRegistryDetachCallback callback) → void -
Available on LifecycleOwner, provided by the LifecycleCallbackManager extension
-
nextLifecycleEvent(
LifecycleEvent event) → Future< LifecycleEvent> -
Available on ILifecycleRegistry, provided by the LifecycleRegistryMixinExt extension
-
nextLifecycleResumedState(
) → Future< LifecycleState> -
Available on ILifecycleRegistry, provided by the LifecycleRegistryMixinExt extension
-
nextLifecycleResumeEvent(
) → Future< LifecycleEvent> -
Available on ILifecycleRegistry, provided by the LifecycleRegistryMixinExt extension
-
nextLifecycleState(
LifecycleState state) → Future< LifecycleState> -
Available on ILifecycleRegistry, provided by the LifecycleRegistryMixinExt extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerLifecycleObserver(
LifecycleObserver observer, {LifecycleState? startWith, bool fullCycle = true}) → void -
Available on ILifecycleRegistry, provided by the LifecycleObserverRegisterSupport extension
-
registerLifecycleObserverToOwner<
LO extends LifecycleOwner> (LifecycleObserver observer, [bool cycleCompanionOwner = false]) → void -
Available on ILifecycleRegistry, provided by the LifecycleObserverRegisterSupport extension
-
removeLifecycleObserver(
LifecycleObserver observer, {LifecycleState? willEnd, bool? fullCycle}) → void -
override
-
removeOwnerAttachCallback(
LifecycleOwnerAttachCallback callback) → void -
Available on LifecycleOwner, provided by the LifecycleCallbackManager extension
-
removeOwnerDetachCallback(
LifecycleOwnerDetachCallback callback) → void -
Available on LifecycleOwner, provided by the LifecycleCallbackManager extension
-
removeRegistryAttachCallback(
LifecycleRegistryAttachCallback callback) → void -
Available on LifecycleOwner, provided by the LifecycleCallbackManager extension
-
removeRegistryDetachCallback(
LifecycleRegistryDetachCallback callback) → void -
Available on LifecycleOwner, provided by the LifecycleCallbackManager extension
-
toLifecycle(
) → Lifecycle -
Available on ILifecycle, provided by the LifecycleConvertExt extension
-
toLifecycleRegistry(
) → ILifecycleRegistry -
Available on ILifecycle, provided by the LifecycleConvertExt extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited